@@ -16,19 +16,21 @@ from .lookups import ChoicesView
 class _SetUserCrudView(BaseCrudView):
     def get(self, request, *args, **kwargs):
         return super(_SetUserCrudView, self).get(
-            initkwargs=dict(user=request.resource_owner), *args, **kwargs)
+            request=request, initkwargs=dict(user=request.resource_owner), *args, **kwargs)
 
     def post(self, request, *args, **kwargs):
-        return super(_SetUserCrudView, self).post(files=request._files.dict(), body=request._post.dict(),
-                                                  initkwargs=dict(user=request.resource_owner), *args, **kwargs)
+        return super(_SetUserCrudView, self).post(
+            request=request, files=request._files.dict(), body=request._post.dict(),
+            initkwargs=dict(user=request.resource_owner), *args, **kwargs)
 
     def put(self, request, *args, **kwargs):
-        return super(_SetUserCrudView, self).put(files=request._files.dict(), body=request._post.dict(),
-                                                 initkwargs=dict(user=request.resource_owner), *args, **kwargs)
+        return super(_SetUserCrudView, self).put(
+            request=request, files=request._files.dict(), body=request._post.dict(),
+            initkwargs=dict(user=request.resource_owner), *args, **kwargs)
 
     def delete(self, request, *args, **kwargs):
         return super(_SetUserCrudView, self).delete(
-            initkwargs=dict(user=request.resource_owner), *args, **kwargs)
+            request=request, initkwargs=dict(user=request.resource_owner), *args, **kwargs)
 
 
 @method_decorator([csrf_exempt, view_catch_error], name='dispatch')
